"""Layout constants for MarkdownDeck."""

# Standard layout constants
HEADER_HEIGHT = 90.0  # Height for header zone
FOOTER_HEIGHT = 30.0  # Height for footer zone
BODY_TOP_ADJUSTMENT = 5.0  # Adjustment to minimize excess spacing between header and body
VERTICAL_SPACING = 10.0  # Default vertical spacing between elements
HORIZONTAL_SPACING = 10.0  # Default horizontal spacing between elements
VERTICAL_SPACING_REDUCTION = 0.7  # 30% reduction for related elements

# Element padding constants
TITLE_PADDING = 5.0  # Padding for title elements
SUBTITLE_PADDING = 4.0  # Padding for subtitle elements
QUOTE_PADDING = 8.0  # Padding for quote elements
DEFAULT_TEXT_PADDING = 3.0  # Default padding for text elements

# Minimum element heights
MIN_SECTION_HEIGHT = 20.0  # Minimum section height in points
MIN_ELEMENT_HEIGHT = 10.0  # Absolute minimum element height

# Default width fractions (relative to max content width)
TITLE_WIDTH_FRACTION = 0.9  # Title takes 90% of max content width
SUBTITLE_WIDTH_FRACTION = 0.85  # Subtitle takes 85% of max content width
QUOTE_WIDTH_FRACTION = 0.9  # Quote takes 90% of max content width
IMAGE_WIDTH_FRACTION = 0.6  # Default image width as fraction of max content width
